@@ -1,4 +1,4 @@
-// Copyright (c) 2022 CNES
+// Copyright (c) 2023 CNES
 //
 // All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
@@ -101,7 +101,7 @@ class Abstract {
   /// Search for the index corresponding to the requested value.
   ///
   /// @param coordinate position in this coordinate system
-  /// @param bounded if true, returns "-1" if the value is located outside this
+  /// @param bounded if false, returns "-1" if the value is located outside this
   /// coordinate system, otherwise the value of the first element if the value
   /// is located before, or the value of the last element of this container if
   /// the requested value is located after.
@@ -382,6 +382,11 @@ class AbstractRegular : public Abstract<T> {
     if (num == 0) {
       throw std::invalid_argument("unable to create an empty container.");
     }
+    if (start == stop) {
+      throw std::invalid_argument(
+          "unable to create a container with a single "
+          "value.");
+    }
     step_ = num == 1 ? stop - start : (stop - start) / (num - 1);
     // The inverse step of this axis is stored in order to optimize the search
     // for an index for a given value by avoiding a division.
