@@ -14,6 +14,7 @@
 #include <vector>
 
 #include "pyinterp/detail/geometry/point.hpp"
+#include "pyinterp/detail/math/kriging.hpp"
 #include "pyinterp/detail/math/radial_basis_functions.hpp"
 #include "pyinterp/detail/math/window_functions.hpp"
 
@@ -278,8 +279,8 @@ class RTree {
   /// neighbors used in the calculation.
   template <typename Strategy>
   auto inverse_distance_weighting(const Point &point, const Strategy &strategy,
-                                  coordinate_t radius, uint32_t k, uint32_t p,
-                                  bool within) const
+                                  const coordinate_t radius, const uint32_t k,
+                                  const uint32_t p, const bool within) const
       -> std::pair<coordinate_t, uint32_t> {
     coordinate_t result = 0;
     coordinate_t total_weight = 0;
@@ -325,12 +326,44 @@ class RTree {
   ///
   /// Overload of the inverse_distance_weighting method with the default
   /// strategy.
-  auto inverse_distance_weighting(const Point &point, coordinate_t radius,
-                                  uint32_t k, uint32_t p, bool within) const {
+  auto inverse_distance_weighting(const Point &point, const coordinate_t radius,
+                                  const uint32_t k, const uint32_t p,
+                                  const bool within) const {
     return inverse_distance_weighting(
         point, boost::geometry::default_strategy(), radius, k, p, within);
   }
 
+  /// Kriging interpolation of the value at the requested position.
+  ///
+  /// @param point Point of interest.
+  /// @param radius The maximum radius of the search.
+  /// @param k The number of nearest neighbors to be used for calculating the
+  /// interpolated value.
+  /// @param within If true, the method ensures that the neighbors found are
+  /// located around the point of interest. In other words, this parameter
+  /// ensures that the calculated values will not be extrapolated.
+  /// @param kriging The kriging model to be used.
+  /// @return a tuple containing the interpolated value and the number of
+  /// neighbors used in the calculation.
+  auto universal_kriging(const Point &point, const coordinate_t radius,
+                         const uint32_t k, const bool within,
+                         const math::Kriging<promotion_t> &kriging) const
+      -> std::pair<coordinate_t, uint32_t> {
+    auto [coordinates, values] =
+        within ? nearest_within(point, boost::geometry::default_strategy(),
+                                radius, k)
+               : nearest(point, boost::geometry::default_strategy(), radius, k);
+    if (values.size() == 0) {
+      return std::make_pair(std::numeric_limits<promotion_t>::quiet_NaN(), 0);
+    }
+    auto requested_point = Eigen::Vector3<promotion_t>(
+        boost::geometry::get<0>(point), boost::geometry::get<1>(point),
+        boost::geometry::get<2>(point));
+    return std::make_pair(
+        kriging.universal_kriging(coordinates, values, requested_point),
+        static_cast<uint32_t>(coordinates.cols()));
+  }
+
   /// Search for the nearest K neighbors of a given point using the given
   /// strategy.
   ///
@@ -461,7 +494,8 @@ class RTree {
   template <typename Strategy>
   auto radial_basis_function(const Point &point, const Strategy &strategy,
                              const math::RBF<promotion_t> &rbf,
-                             coordinate_t radius, uint32_t k, bool within) const
+                             const coordinate_t radius, const uint32_t k,
+                             const bool within) const
       -> std::pair<promotion_t, uint32_t> {
     auto [coordinates, values] =
         within ? nearest_within(point, strategy, radius, k)
@@ -484,7 +518,8 @@ class RTree {
   /// Overload of the radial_basis_function method with the default strategy.
   auto radial_basis_function(const Point &point,
                              const math::RBF<promotion_t> &rbf,
-                             coordinate_t radius, uint32_t k, bool within) const
+                             const coordinate_t radius, const uint32_t k,
+                             const bool within) const
       -> std::pair<promotion_t, uint32_t> {
     return radial_basis_function(point, boost::geometry::default_strategy(),
                                  rbf, radius, k, within);
@@ -496,7 +531,6 @@ class RTree {
   /// @param point Point of interest
   /// @param strategy strategy used to compute the distance.
   /// @param wf The window function to be used.
-  /// @param radius The maximum radius of the search.
   /// @param k The number of nearest neighbors to be used for calculating the
   /// interpolated value.
   /// @param within If true, the method ensures that the neighbors found are
@@ -507,8 +541,9 @@ class RTree {
   template <typename Strategy>
   auto window_function(const Point &point, const Strategy &strategy,
                        const math::WindowFunction<coordinate_t> &wf,
-                       const coordinate_t arg, coordinate_t radius, uint32_t k,
-                       bool within) const -> std::pair<coordinate_t, uint32_t> {
+                       const coordinate_t arg, const coordinate_t radius,
+                       const uint32_t k, const bool within) const
+      -> std::pair<coordinate_t, uint32_t> {
     coordinate_t result = 0;
     coordinate_t total_weight = 0;
 
@@ -516,10 +551,19 @@ class RTree {
         within ? query_within(point, strategy, k) : query(point, strategy, k);
     uint32_t neighbors = 0;
 
+    // Get the distance of the furthest neighbor if radius is not specified.
+    const auto furthest_neighbor =
+        radius == std::numeric_limits<coordinate_t>::max()
+            ? (nearest.size() > 0 ? nearest.rbegin()->first : 0)
+            : radius;
+
     for (const auto &item : nearest) {
       const auto distance = item.first;
+      if (distance > radius) {
+        break;
+      }
 
-      auto wk = wf(static_cast<coordinate_t>(distance), radius, arg);
+      auto wk = wf(static_cast<coordinate_t>(distance), furthest_neighbor, arg);
       total_weight += wk;
       result += item.second * wk;
       ++neighbors;
@@ -540,8 +584,9 @@ class RTree {
   /// Overload of the window_function method with the default strategy.
   auto window_function(const Point &point,
                        const math::WindowFunction<coordinate_t> &wf,
-                       const coordinate_t arg, coordinate_t radius, uint32_t k,
-                       bool within) const -> std::pair<coordinate_t, uint32_t> {
+                       const coordinate_t arg, const coordinate_t radius,
+                       const uint32_t k, const bool within) const
+      -> std::pair<coordinate_t, uint32_t> {
     return window_function(point, boost::geometry::default_strategy(), wf, arg,
                            radius, k, within);
   }
