@@ -3,9 +3,12 @@
 // All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 #pragma once
+#include <Eigen/Core>
 #include <limits>
 #include <type_traits>
 
+#include "pyinterp/eigen.hpp"
+
 namespace pyinterp::detail::math {
 
 /// Linear interpolation
