@@ -36,9 +36,16 @@ class Crossover {
   /// Get the crossover point between the two passes.
   ///
   /// @return the crossover location.
+  /// @throw std::runtime_error if there is more than one crossover point.
   [[nodiscard]] auto search(const std::optional<Spheroid>& wgs) const
       -> std::optional<Point>;
 
+  /// Get the list of the crossover points between the two passes.
+  ///
+  /// @return the list of crossover locations.
+  [[nodiscard]] auto search_all(const std::optional<Spheroid>& wgs) const
+      -> std::vector<Point>;
+
   /// Test if there is a crossover point between the two passes.
   ///
   /// @return true if there is a crossover point.
@@ -105,4 +112,28 @@ auto crossover(const Eigen::Ref<const Eigen::VectorXd>& lon1,
                const std::optional<Spheroid>& wgs, bool cartesian_plane)
     -> std::optional<std::tuple<Point, std::tuple<size_t, size_t>>>;
 
+/// Calculate all the crossover points between two half-orbits.
+///
+/// @param[in] lon1 Longitude, in degrees, of the first half-orbit.
+/// @param[in] lat1 Latitude, in degrees, of the first half-orbit.
+/// @param[in] lon2 Longitude, in degrees, of the second half-orbit.
+/// @param[in] lat2 Latitude, in degrees, of the second half-orbit.
+/// @param[in] predicate the maximal distance predicate, in meters, to discard
+/// the crossover point if it is too far.
+/// @param[in] strategy the distance strategy.
+/// @param[in] wgs the spheroid to use.
+/// @param[in] cartesian_plane if true, the crossing point is calculated in the
+/// Cartesian plane, otherwise in the geodesic plane. Warning, the calculation
+/// in a Cartesian plane is valid if the entry positions in the half-orbits are
+/// not too far from each other (less than 10 km).
+/// @return A list of tuples containing the crossover point and the indexes
+/// closest to the crossover point on both half orbits.
+auto crossover_list(const Eigen::Ref<const Eigen::VectorXd>& lon1,
+                    const Eigen::Ref<const Eigen::VectorXd>& lat1,
+                    const Eigen::Ref<const Eigen::VectorXd>& lon2,
+                    const Eigen::Ref<const Eigen::VectorXd>& lat2,
+                    double predicate, const DistanceStrategy strategy,
+                    const std::optional<Spheroid>& wgs, bool cartesian_plane)
+    -> std::vector<std::tuple<Point, std::tuple<size_t, size_t>>>;
+
 }  // namespace pyinterp::geodetic
