@@ -19,6 +19,7 @@ namespace pyinterp::geodetic {
 
 /// Forward declaration
 class Box;
+class LineString;
 class MultiPolygon;
 
 class Polygon : public boost::geometry::model::polygon<Point> {
@@ -120,11 +121,26 @@ class Polygon : public boost::geometry::model::polygon<Point> {
   /// Calculates the intersection between this instance and another one.
   [[nodiscard]] auto intersection(const Polygon &other) const -> MultiPolygon;
 
+  /// Calculates the intersection between this instance and another one.
+  [[nodiscard]] auto intersection(const LineString &other) const -> LineString;
+
   /// Checks if this polygon intersects with another one.
   [[nodiscard]] auto intersects(const Polygon &other) const -> bool {
     return boost::geometry::intersects(*this, other);
   }
 
+  /// Simplifies this polygon.
+  [[nodiscard]] auto simplify(double tolerance) const -> Polygon;
+
+  /// Calculates the difference between this instance and another one.
+  [[nodiscard]] auto difference(const Polygon &other) const -> MultiPolygon;
+
+  /// Returns the perimeter of this polygon.
+  [[nodiscard]] auto perimeter(const std::optional<Spheroid> &wgs) const
+      -> double {
+    return geodetic::perimeter(*this, wgs);
+  }
+
   /// Checks if this polygon touches another one.
   [[nodiscard]] auto touches(const Polygon &other) const -> bool {
     return boost::geometry::touches(*this, other);
