@@ -30,6 +30,9 @@ using RadialBasisFunction = detail::math::RadialBasisFunction;
 /// Type of window functions exposed in the Python module.
 using WindowFunction = detail::math::window::Function;
 
+/// Type of covariance functions exposed in the Python module.
+using CovarianceFunction = detail::math::CovarianceFunction;
+
 /// RTree spatial index for geodetic point
 ///
 /// @note
@@ -256,7 +259,8 @@ class RTree : public detail::geometry::RTree<Point, Type> {
   }
 
   /// TODO
-  auto window_function(const array_t &coordinates, const coordinate_t &radius,
+  auto window_function(const array_t &coordinates,
+                       const std::optional<coordinate_t> &radius,
                        const uint32_t k, const WindowFunction wf,
                        const std::optional<coordinate_t> &arg,
                        const bool within, const size_t num_threads) const
@@ -265,17 +269,43 @@ class RTree : public detail::geometry::RTree<Point, Type> {
     switch (coordinates.shape(1)) {
       case dimension_t::value - 1:
         return _window_function<dimension_t::value - 1>(
-            &RTree<Point, Type>::from_lon_lat, coordinates, radius, k, wf,
+            &RTree<Point, Type>::from_lon_lat, coordinates,
+            radius.value_or(std::numeric_limits<coordinate_t>::max()), k, wf,
             arg.value_or(0), within, num_threads);
       case dimension_t::value:
         return _window_function<dimension_t::value>(
-            &RTree<Point, Type>::from_lon_lat_alt, coordinates, radius, k, wf,
+            &RTree<Point, Type>::from_lon_lat_alt, coordinates,
+            radius.value_or(std::numeric_limits<coordinate_t>::max()), k, wf,
             arg.value_or(0), within, num_threads);
       default:
         throw std::invalid_argument(RTree<Point, Type>::invalid_shape());
     }
   }
 
+  auto universal_kriging(const array_t &coordinates,
+                         const std::optional<coordinate_t> &radius,
+                         const uint32_t k, const CovarianceFunction cov,
+                         const coordinate_t sigma, const coordinate_t lambda,
+                         const bool within, const size_t num_threads) const
+      -> pybind11::tuple {
+    detail::check_array_ndim("coordinates", 2, coordinates);
+
+    switch (coordinates.shape(1)) {
+      case dimension_t::value - 1:
+        return _universal_kriging<dimension_t::value - 1>(
+            &RTree<Point, Type>::from_lon_lat, coordinates,
+            radius.value_or(std::numeric_limits<coordinate_t>::max()), k, cov,
+            sigma, lambda, within, num_threads);
+      case dimension_t::value:
+        return _universal_kriging<dimension_t::value>(
+            &RTree<Point, Type>::from_lon_lat, coordinates,
+            radius.value_or(std::numeric_limits<coordinate_t>::max()), k, cov,
+            sigma, lambda, within, num_threads);
+      default:
+        throw std::invalid_argument(RTree<Point, Type>::invalid_shape());
+    }
+  }
+
   /// Get a tuple that fully encodes the state of this instance
   [[nodiscard]] auto getstate() const -> pybind11::tuple {
     auto x = pybind11::array_t<coordinate_t>(pybind11::array::ShapeContainer{
@@ -648,6 +678,65 @@ class RTree : public detail::geometry::RTree<Point, Type> {
     return pybind11::make_tuple(data, neighbors);
   }
 
+  /// Linear interpolation
+  template <size_t M>
+  auto _universal_kriging(Converter converter,
+                          const pybind11::array_t<coordinate_t> &coordinates,
+                          const coordinate_t radius, const uint32_t k,
+                          const CovarianceFunction &cov,
+                          const coordinate_t sigma, const coordinate_t lambda,
+                          const bool within, const size_t num_threads) const
+      -> pybind11::tuple {
+    auto _coordinates = coordinates.template unchecked<2>();
+    auto size = coordinates.shape(0);
+
+    auto kriging_handler =
+        detail::math::Kriging<promotion_t>(sigma, lambda, cov);
+
+    // Allocation of result vectors.
+    auto data =
+        pybind11::array_t<promotion_t>(pybind11::array::ShapeContainer{size});
+    auto neighbors =
+        pybind11::array_t<uint32_t>(pybind11::array::ShapeContainer{size});
+
+    auto _data = data.template mutable_unchecked<1>();
+    auto _neighbors = neighbors.template mutable_unchecked<1>();
+
+    {
+      pybind11::gil_scoped_release release;
+
+      // Captures the detected exceptions in the calculation function
+      // (only the last exception captured is kept)
+      auto except = std::exception_ptr(nullptr);
+
+      detail::dispatch(
+          [&](size_t start, size_t end) {
+            try {
+              auto point = Point();
+
+              for (size_t ix = start; ix < end; ++ix) {
+                point = std::move(
+                    std::invoke(converter, *this,
+                                Eigen::Map<const Vector<coordinate_t>>(
+                                    &_coordinates(ix, 0), M)));
+                auto result = base_t::universal_kriging(
+                    point, radius, k, within, kriging_handler);
+                _data(ix) = result.first;
+                _neighbors(ix) = result.second;
+              }
+            } catch (...) {
+              except = std::current_exception();
+            }
+          },
+          size, num_threads);
+
+      if (except != nullptr) {
+        std::rethrow_exception(except);
+      }
+    }
+    return pybind11::make_tuple(data, neighbors);
+  }
+
   /// Radial basis function interpolation
   template <size_t M>
   auto _rbf(Converter converter,
