@@ -7,6 +7,7 @@
 #include <pybind11/pybind11.h>
 
 #include "pyinterp/geodetic/box.hpp"
+#include "pyinterp/geodetic/line_string.hpp"
 #include "pyinterp/geodetic/multipolygon.hpp"
 
 namespace pyinterp::geodetic {
@@ -109,4 +110,22 @@ auto Polygon::intersection(const Polygon &other) const -> MultiPolygon {
   return result;
 }
 
+auto Polygon::intersection(const LineString &other) const -> LineString {
+  auto result = LineString();
+  boost::geometry::intersection(*this, other, result);
+  return result;
+}
+
+auto Polygon::simplify(double tolerance) const -> Polygon {
+  auto result = Polygon();
+  boost::geometry::simplify(*this, result, tolerance);
+  return result;
+}
+
+auto Polygon::difference(const Polygon &other) const -> MultiPolygon {
+  auto result = MultiPolygon();
+  boost::geometry::difference(*this, other, result);
+  return result;
+}
+
 }  // namespace pyinterp::geodetic
