@@ -84,6 +84,25 @@ Args:
 
 Returns:
     The distance between the two points in meters.
+)__doc__",
+          py::call_guard<py::gil_scoped_release>())
+      .def(
+          "azimuth",
+          [](const geodetic::Point &self, const geodetic::Point &other,
+             const std::optional<geodetic::Spheroid> &wgs) -> double {
+            return self.azimuth(other, wgs);
+          },
+          py::arg("other"), py::arg("wgs") = std::nullopt,
+          R"__doc__(
+Calculate the azimuth between the two points.
+
+Args:
+    other: The other point to consider.
+    wgs: The spheroid used to calculate the distance. If not provided, the
+        WGS-84 spheroid is used.
+
+Returns:
+    The azimuth between the two points in degrees.
 )__doc__",
           py::call_guard<py::gil_scoped_release>())
       .def("to_geojson", &geodetic::Point::to_geojson,
@@ -388,6 +407,64 @@ Returns:
            py::call_guard<py::gil_scoped_release>())
       .def("num_interior_rings", &geodetic::Polygon::num_interior_rings,
            "Returns the number of the interior rings.")
+      .def_property_readonly(
+          "is_valid",
+          [](const geodetic::Polygon &self) {
+            return boost::geometry::is_valid(self);
+          },
+          "Returns whether the polygon is valid.")
+      .def(
+          "correct",
+          [](const geodetic::Polygon &self) {
+            auto polygon = self;
+            boost::geometry::correct(polygon);
+            return polygon;
+          },
+          R"__doc__(
+Corrects a Polygon
+
+Returns:
+    The corrected polygon.
+)__doc__",
+          py::call_guard<py::gil_scoped_release>())
+      .def("simplify", &geodetic::Polygon::simplify, py::arg("tolerance"),
+           R"__doc__(
+Simplifies a polygon.
+
+Args:
+    tolerance: The tolerance to use when simplifying the polygon.
+
+Returns:
+    The simplified polygon.
+)__doc__",
+           py::call_guard<py::gil_scoped_release>())
+      .def(
+          "difference",
+          [](const geodetic::Polygon &self, const geodetic::Polygon &other)
+              -> geodetic::MultiPolygon { return self.difference(other); },
+          py::arg("other"),
+          R"__doc__(
+Computes the difference of this polygon with another.
+
+Args:
+    other: The polygon to compute the difference with.
+
+Returns:
+    The difference of this polygon with the provided polygon.
+)__doc__",
+          py::call_guard<py::gil_scoped_release>())
+      .def("perimeter", &geodetic::Polygon::perimeter,
+           py::arg("wgs") = std::nullopt,
+           R"__doc__(
+Computes the perimeter of this polygon.
+
+Args:
+    wgs: The WGS84 ellipsoid to use when computing the perimeter.
+
+Returns:
+    The perimeter of this polygon.
+)__doc__",
+           py::call_guard<py::gil_scoped_release>())
       .def(
           "union",
           [](const geodetic::Polygon &self, const geodetic::Polygon &other)
@@ -414,6 +491,23 @@ Args:
     other: The polygon to compute the intersection with.
 Returns:
     The intersection of this polygon with the provided polygon.
+)__doc__",
+          py::call_guard<py::gil_scoped_release>())
+      .def(
+          "intersection",
+          [](const geodetic::Polygon &self,
+             const geodetic::LineString &line_string) -> geodetic::LineString {
+            return self.intersection(line_string);
+          },
+          py::arg("line_string"),
+          R"__doc__(
+Computes the intersection of this polygon with a line string.
+
+Args:
+    other: The line string to compute the intersection with.
+
+Returns:
+    The intersection of this polygon with the provided line string.
 )__doc__",
           py::call_guard<py::gil_scoped_release>())
       .def(
@@ -1106,6 +1200,50 @@ Args:
 
 Returns:
     The simplified linestring.
+)__doc__",
+          py::call_guard<py::gil_scoped_release>())
+      .def(
+          "closest_point",
+          [](const geodetic::LineString &self, const geodetic::Point &point,
+             const std::optional<geodetic::Spheroid> &wgs) -> geodetic::Point {
+            return self.closest_point(point, wgs);
+          },
+          py::arg("point"), py::arg("wgs") = std::nullopt,
+          R"__doc__(
+Computes the closest point on this linestring to the given point.
+
+Args:
+    point: The point to test.
+    wgs: The World Geodetic System to use. Defaults to WGS84.
+
+Returns:
+    The closest point on this linestring to the given point.
+)__doc__",
+          py::call_guard<py::gil_scoped_release>())
+      .def(
+          "closest_point",
+          [](const geodetic::LineString &self,
+             const Eigen::Ref<const Eigen::VectorXd> &lon,
+             const Eigen::Ref<const Eigen::VectorXd> &lat,
+             const std::optional<geodetic::Spheroid> &wgs,
+             int num_threads) -> std::tuple<Eigen::VectorXd, Eigen::VectorXd> {
+            return self.closest_point(lon, lat, wgs, num_threads);
+          },
+          py::arg("lon"), py::arg("lat"), py::arg("wgs") = std::nullopt,
+          py::arg("num_threads") = 0,
+          R"__doc__(
+Computes the closest point on this linestring to the given points.
+
+Args:
+    lon: The longitude of the points to test.
+    lat: The latitude of the points to test.
+    wgs: The World Geodetic System to use. Defaults to WGS84.
+    num_threads: The number of threads to use. Defaults to 0, which means
+        that the number of threads is automatically determined.
+
+Returns:
+    A tuple containing the closest point on this linestring to the given
+    points.
 )__doc__",
           py::call_guard<py::gil_scoped_release>())
       .def(py::pickle(
@@ -1150,6 +1288,23 @@ Args:
 
 Returns:
     The crossover or None if there is no crossover.
+
+Raises:
+    RuntimeError: If there is more than one crossover.
+)__doc__",
+           py::call_guard<py::gil_scoped_release>())
+      .def("search_all", &geodetic::Crossover::search_all,
+           py::arg("wgs") = std::nullopt,
+           R"__doc__(
+Get the list of the crossover points between the two passes.
+
+Args:
+    wgs: If specified, searches for the intersection using geographic
+        coordinates with the specified spheroid, otherwise searches for the
+        intersection using spherical coordinates.
+
+Returns:
+    The crossover points.
 )__doc__",
            py::call_guard<py::gil_scoped_release>())
       .def("exists", &geodetic::Crossover::exists,
@@ -1307,7 +1462,8 @@ Returns:
     calculation.
 )__doc__")
       .def("radial_basis_function", &geodetic::RTree::radial_basis_function,
-           py::arg("lon"), py::arg("lat"), py::arg("radius"), py::arg("k") = 9,
+           py::arg("lon"), py::arg("lat"), py::arg("radius") = std::nullopt,
+           py::arg("k") = 9,
            py::arg("rbf") = math::RadialBasisFunction::Multiquadric,
            py::arg("epsilon") = std::optional<double>(), py::arg("smooth") = 0,
            py::arg("within") = true, py::arg("num_threads") = 0,
@@ -1340,7 +1496,7 @@ Returns:
     calculation.
 )__doc__")
       .def("window_function", &geodetic::RTree::window_function, py::arg("lon"),
-           py::arg("lat"), py::arg("radius"), py::arg("k") = 9,
+           py::arg("lat"), py::arg("radius") = std::nullopt, py::arg("k") = 9,
            py::arg("wf") = math::window::Function::kHamming,
            py::arg("arg") = std::nullopt, py::arg("within") = true,
            py::arg("num_threads") = 0,
@@ -1622,9 +1778,9 @@ Args:
 
   init_geodetic_point(m);
   init_geodetic_box(box);
+  init_geodetic_linestring(m);
   init_geodetic_polygon(polygon);
   init_geodetic_multipolygon(multipolygon);
-  init_geodetic_linestring(m);
   init_geodetic_crossover(m);
   init_geodetic_rtree(m);
 
@@ -1726,19 +1882,19 @@ Returns:
         py::call_guard<py::gil_scoped_release>());
 
   m.def(
-      "calculate_crossover",
-      [](const Eigen::Ref<const Eigen::VectorXd> &lon1,
-         const Eigen::Ref<const Eigen::VectorXd> &lat1,
-         const Eigen::Ref<const Eigen::VectorXd> &lon2,
-         const Eigen::Ref<const Eigen::VectorXd> &lat2,
-         const std::optional<double> &predicate, const std::string &strategy,
-         const std::optional<geodetic::Spheroid> &wgs,
-         const bool cartesian_plane) {
-        return geodetic::crossover(
-            lon1, lat1, lon2, lat2, predicate.value_or(40'075'000.0),
-            parse_distance_strategy(strategy), wgs, cartesian_plane);
-      },
-      R"__doc__(
+       "calculate_crossover",
+       [](const Eigen::Ref<const Eigen::VectorXd> &lon1,
+          const Eigen::Ref<const Eigen::VectorXd> &lat1,
+          const Eigen::Ref<const Eigen::VectorXd> &lon2,
+          const Eigen::Ref<const Eigen::VectorXd> &lat2,
+          const std::optional<double> &predicate, const std::string &strategy,
+          const std::optional<geodetic::Spheroid> &wgs,
+          const bool cartesian_plane) {
+         return geodetic::crossover(
+             lon1, lat1, lon2, lat2, predicate.value_or(40'075'000.0),
+             parse_distance_strategy(strategy), wgs, cartesian_plane);
+       },
+       R"__doc__(
 Calculate the crossover coordinates from the nadir coordinates.
 
 Args:
@@ -1759,8 +1915,47 @@ Return:
     A tuple containing the crossover coordinates and the indices of the nearest
     nadir points on the first and second line.
 )__doc__",
-      py::arg("lon1"), py::arg("lat1"), py::arg("lon2"), py::arg("lat2"),
-      py::arg("predicate") = std::nullopt, py::arg("strategy") = "thomas",
-      py::arg("wgs") = std::nullopt, py::arg("cartesian_plane") = true,
-      py::call_guard<py::gil_scoped_release>());
+       py::arg("lon1"), py::arg("lat1"), py::arg("lon2"), py::arg("lat2"),
+       py::arg("predicate") = std::nullopt, py::arg("strategy") = "thomas",
+       py::arg("wgs") = std::nullopt, py::arg("cartesian_plane") = true,
+       py::call_guard<py::gil_scoped_release>())
+      .def(
+          "calculate_crossover_list",
+          [](const Eigen::Ref<const Eigen::VectorXd> &lon1,
+             const Eigen::Ref<const Eigen::VectorXd> &lat1,
+             const Eigen::Ref<const Eigen::VectorXd> &lon2,
+             const Eigen::Ref<const Eigen::VectorXd> &lat2,
+             const std::optional<double> &predicate,
+             const std::string &strategy,
+             const std::optional<geodetic::Spheroid> &wgs,
+             const bool cartesian_plane) {
+            return geodetic::crossover_list(
+                lon1, lat1, lon2, lat2, predicate.value_or(40'075'000.0),
+                parse_distance_strategy(strategy), wgs, cartesian_plane);
+          },
+          R"__doc__(
+Calculate all crossover coordinates from the nadir coordinates.
+
+Args:
+    lon1: Longitudes in degrees of the nadir points of the first line.
+    lat1: Latitudes in degrees of the nadir points of the first line.
+    lon2: Longitudes in degrees of the nadir points of the second line.
+    lat2: Latitudes in degrees of the nadir points of the second line.
+    predicate: The maximum distance allowed between the nadir points closest
+        to the crossing point.
+    strategy: The calculation method used to calculate the distance. This
+        parameter can take the values "andoyer", "thomas" or "vincenty".
+    wgs: The spheroid used to calculate the distance. Defaults to ``None``,
+        which means the WGS-84 spheroid is used.
+    cartesian_plane: If ``True``, the crossing point is calculated in the
+        cartesian plane. Defaults to ``False``.
+
+Return:
+    A list of tuples containing the crossover coordinates and the indices of
+    the nearest nadir points on the first and second line.
+)__doc__",
+          py::arg("lon1"), py::arg("lat1"), py::arg("lon2"), py::arg("lat2"),
+          py::arg("predicate") = std::nullopt, py::arg("strategy") = "thomas",
+          py::arg("wgs") = std::nullopt, py::arg("cartesian_plane") = true,
+          py::call_guard<py::gil_scoped_release>());
 }
