@@ -137,8 +137,8 @@ Returns:
 )__doc__")
               .c_str())
       .def("inverse_distance_weighting", &RTree::inverse_distance_weighting,
-           py::arg("coordinates"), py::arg("radius"), py::arg("k") = 9,
-           py::arg("p") = 2, py::arg("within") = true,
+           py::arg("coordinates"), py::arg("radius") = std::nullopt,
+           py::arg("k") = 9, py::arg("p") = 2, py::arg("within") = true,
            py::arg("num_threads") = 0,
            (R"__doc__(
 Interpolation of the value at the requested position by inverse distance
@@ -165,7 +165,8 @@ Returns:
 )__doc__")
                .c_str())
       .def("radial_basis_function", &RTree::radial_basis_function,
-           py::arg("coordinates"), py::arg("radius"), py::arg("k") = 9,
+           py::arg("coordinates"), py::arg("radius") = std::nullopt,
+           py::arg("k") = 9,
            py::arg("rbf") = pyinterp::RadialBasisFunction::Multiquadric,
            py::arg("epsilon") = std::optional<typename RTree::promotion_t>(),
            py::arg("smooth") = 0, py::arg("within") = true,
@@ -198,7 +199,7 @@ Returns:
 )__doc__")
                .c_str())
       .def("window_function", &RTree::window_function, py::arg("coordinates"),
-           py::arg("radius"), py::arg("k") = 9,
+           py::arg("radius") = std::nullopt, py::arg("k") = 9,
            py::arg("wf") = pyinterp::WindowFunction::kHamming,
            py::arg("arg") = std::nullopt, py::arg("within") = true,
            py::arg("num_threads") = 0,
@@ -222,6 +223,40 @@ Args:
         which is useful for debugging. Defaults to ``0``.
 Returns:
     The interpolated value and the number of neighbors used for the calculation.
+)__doc__")
+               .c_str())
+      .def("universal_kriging", &RTree::universal_kriging,
+           py::arg("coordinates"), py::arg("radius") = std::nullopt,
+           py::arg("k") = 9,
+           py::arg("covariance") = pyinterp::CovarianceFunction::kMatern_32,
+           py::arg("sigma") = 1, py::arg("alpha") = 1'000'000,
+           py::arg("within") = true, py::arg("num_threads") = 0,
+           (R"__doc__(
+Universal Kriging interpolation of the value at the requested position.
+
+Args:
+    )__doc__" +
+            coordinates_help<dimension_t::value>() + R"__doc__(
+    radius: The maximum radius of the search (m). Default to the largest value
+        that can be represented on a float.
+    k: The number of nearest neighbors to be used for calculating the
+        interpolated value. Defaults to ``9``.
+    covariance: The covariance function to be used. Defaults to
+        :py:attr:`pyinterp.core.CovarianceFunction.Matern_52`.
+    sigma: The magnitude parameter. Determines the overall scale of the
+        covariance function. It represents the maximum possible covariance
+        between two points. Defaults to ``1``.
+    alpha: Decay rate parameter. Determines the rate at which the covariance
+        decreases. It represents the spatial scale of the covariance function
+        and can be used to control the smoothness of the spatial dependence
+        structure.
+    within: If true, the method ensures that the neighbors found are located
+        around the point of interest. Defaults to ``true``.
+    num_threads: The number of threads to use for the computation. If 0 all CPUs
+        are used. If 1 is given, no parallel computing code is used at all,
+        which is useful for debugging. Defaults to ``0``.
+Returns:
+    The interpolated value and the number of neighbors used for the calculation.
 )__doc__")
                .c_str())
       .def("value", &RTree::value, py::arg("coordinates"),
