@@ -9,7 +9,7 @@ import pickle
 import numpy as np
 import pytest
 
-from .. import multipolygon_path, polygon_path
+from .. import multipolygon_path, parallel_lines, polygon_path
 from ... import core
 from ...core import geodetic
 
@@ -139,6 +139,12 @@ def test_point_distance():
         acropolis.distance(ulb, strategy='Thomas')
 
 
+def test_point_azimuth():
+    acropolis = core.geodetic.Point(23.725750, 37.971536)
+    ulb = core.geodetic.Point(4.3826169, 50.8119483)
+    assert -40.6961829843325 == pytest.approx(acropolis.azimuth(ulb))
+
+
 def test_point_pickle():
     """Serialization tests."""
     a = core.geodetic.Point(1, 2)
@@ -369,6 +375,21 @@ def test_crossover():
         assert pytest.approx(point.lat, rel=1e-3) == 4.0018282189756835
 
 
+def test_search_all():
+    """Search for all crossovers."""
+    with parallel_lines().open() as stream:
+        data = json.load(stream)
+    l1 = core.geodetic.LineString.from_geojson(
+        data['features'][0]['geometry']['coordinates'])
+    l2 = core.geodetic.LineString.from_geojson(
+        data['features'][1]['geometry']['coordinates'])
+    crossovers = core.geodetic.Crossover(l1, l2).search_all()
+    assert all(
+        isinstance(crossover, core.geodetic.Point) for crossover in crossovers)
+    with pytest.raises(RuntimeError):
+        core.geodetic.Crossover(l1, l1).search()
+
+
 def test_merged_point():
     """Try to compute a crossover from overlay tracks."""
     lon1 = np.array([0, 1, 2, 3, 5, 6, 7, 8], dtype=np.float64)
@@ -399,6 +420,60 @@ def test_merged_point():
             lon1, lat1, lon1 + 10, lat1 + 10, cartesian_plane=flag)
 
 
+def test_line_string_closest():
+    """Calculate the closest point on a line string."""
+    lon1 = np.array([0, 1, 2, 3, 5, 6, 7, 8], dtype=np.float64)
+    lat1 = np.array([0, 1, 2, 3, 5, 6, 7, 8], dtype=np.float64)
+    ls = core.geodetic.LineString(lon1, lat1)
+    point = ls.closest_point(core.geodetic.Point(5, 3))
+    assert pytest.approx(point.lon, rel=1e-5) == 4.00409
+    assert pytest.approx(point.lat, rel=1e-5) == 4.00594
+
+    lon2 = lon1 + 0.5
+    lat2 = lat1
+    lon3, lat3 = ls.closest_point(lon2, lat2)
+    assert np.allclose(
+        lon3,
+        np.array([
+            0.25164205, 1.25152691, 2.25133454, 3.25060547, 5.25029275,
+            6.24978998, 7.24920902, 8.0
+        ]))
+    assert np.allclose(
+        lat3,
+        np.array([[
+            0.25168094, 1.25165222, 2.25154618, 3.25136395, 5.25076241,
+            6.25034513, 7.24984932, 8.0
+        ]]))
+
+
+def test_calculate_crossover_list():
+    """Calculate the location of all crossovers."""
+    with parallel_lines().open() as stream:
+        data = json.load(stream)
+    lon1, lat1 = zip(*data['features'][0]['geometry']['coordinates'])
+    lon2, lat2 = zip(*data['features'][1]['geometry']['coordinates'])
+    lon1 = np.array(lon1, dtype=np.float64)
+    lat1 = np.array(lat1, dtype=np.float64)
+    lon2 = np.array(lon2, dtype=np.float64)
+    lat2 = np.array(lat2, dtype=np.float64)
+
+    crossovers = core.geodetic.calculate_crossover_list(lon1, lat1, lon2, lat2)
+    assert len(crossovers) != 0
+    assert all(
+        isinstance(crossover[0], core.geodetic.Point)
+        for crossover in crossovers)
+    assert all(isinstance(crossover[1], tuple) for crossover in crossovers)
+    assert all(isinstance(crossover[1][0], int) for crossover in crossovers)
+    assert all(isinstance(crossover[1][1], int) for crossover in crossovers)
+
+    crossovers = core.geodetic.calculate_crossover_list(lon1,
+                                                        lat1,
+                                                        lon2,
+                                                        lat2,
+                                                        cartesian_plane=True)
+    assert len(crossovers) != 0
+
+
 def test_missing_crossover():
     """Try to calculate a crossing point when the entry passes do not cross."""
     x1 = np.array([0, 1, 2, 3, 4, 5, 6], dtype=np.float64)
@@ -564,6 +639,38 @@ def test_union_polygon():
     assert len(union) == 1
 
 
+def test_difference_polygon():
+    a = core.geodetic.Polygon.read_wkt(
+        'POLYGON((2 1.3,2.4 1.7,2.8 1.8,3.4 1.2,3.7 1.6,3.4 2,4.1 3,5.3 2.6,'
+        '5.4 1.2,4.9 0.8,2.9 0.7,2 1.3)'
+        '(4.0 2.0, 4.2 1.4, 4.8 1.9, 4.4 2.2, 4.0 2.0))')
+    b = core.geodetic.Polygon.read_wkt(
+        'POLYGON((4.0 -0.5,3.5 1.0,2.0 1.5,3.5 2.0,4.0 3.5,4.5 2.0,6.0 1.5,'
+        '4.5 1.0,4.0 -0.5))')
+    difference = a.difference(b)
+    assert len(difference) == 5
+
+
+def test_simplify_polygon():
+    a = core.geodetic.Polygon.read_wkt(
+        'POLYGON((2 1.3,2.4 1.7,2.8 1.8,3.4 1.2,3.7 1.6,3.4 2,4.1 3,5.3 2.6,'
+        '5.4 1.2,4.9 0.8,2.9 0.7,2 1.3)'
+        '(4.0 2.0, 4.2 1.4, 4.8 1.9, 4.4 2.2, 4.0 2.0))')
+    simplified = a.simplify(100)
+    assert simplified.wkt() == (
+        'POLYGON((5.3 2.6,5.4 1.2,4.9 0.8,2.9 0.7,2 1.3,2.4 1.7,2.8 1.8,'
+        '3.4 1.2,3.7 1.6,3.4 2,4.1 3,5.3 2.6),(4.8 1.9,4.4 2.2,4 2,4.2 1.4,'
+        '4.8 1.9))')
+
+
+def test_perimeter_polygon():
+    a = core.geodetic.Polygon.read_wkt(
+        'POLYGON((2 1.3,2.4 1.7,2.8 1.8,3.4 1.2,3.7 1.6,3.4 2,4.1 3,5.3 2.6,'
+        '5.4 1.2,4.9 0.8,2.9 0.7,2 1.3)'
+        '(4.0 2.0, 4.2 1.4, 4.8 1.9, 4.4 2.2, 4.0 2.0))')
+    assert a.perimeter() == pytest.approx(1420542.81)
+
+
 def test_linestring():
     a = core.geodetic.LineString.from_geojson([[1, 2], [2, 3], [3, 4]])
     assert a.wkt() == 'LINESTRING(1 2,2 3,3 4)'
