@@ -10,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "2023.1.0"
+    return "2023.2.1"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "13 January 2023"
+    return "08 February 2023"
